@@ -20,9 +20,9 @@ LANG=C rpm --checksig kernel-3.19.8-100.fc20.src.rpm | grep -F ': rsa sha1 (md5)
 rpm -ivh kernel-3.19.8-100.fc20.src.rpm || die "Can't install source package."
 
 cd ~/rpmbuild/SOURCES/ || die "Can't chdir to ~/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.5-20190506.tar.gz ]
+if [ ! -r ccs-patch-1.8.6-20190820.tar.gz ]
 then
-    wget -O ccs-patch-1.8.5-20190506.tar.gz 'https://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.5-20190506.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.6-20190820.tar.gz 'https://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.6-20190820.tar.gz' || die "Can't download patch."
 fi
 
 cd ~/rpmbuild/SPECS/ || die "Can't chdir to ~/rpmbuild/SPECS/ ."
@@ -35,7 +35,7 @@ patch << "EOF" || die "Can't patch spec file."
  # (Uncomment the '#' and both spaces below to set the buildid.)
  #
 -# % define buildid .local
-+%define buildid _tomoyo_1.8.5p2
++%define buildid _tomoyo_1.8.6
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
@@ -71,7 +71,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.5-20190506.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.6-20190820.tar.gz
 +patch -sp1 < patches/ccs-patch-3.19-fedora-20.diff
 +
  %endif
