@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.8.5   2015/11/11
+ * Version: 1.8.6   2019/08/20
  */
 
 #include "internal.h"
@@ -541,12 +541,14 @@ char *ccs_realpath(const struct path *path)
 #endif
 		inode = d_backing_inode(sb->s_root);
 		/*
-		 * Use local name for "filesystems without rename() operation"
-		 * or "path without vfsmount" or "absolute name is unavailable"
-		 * cases.
+		 * Use local name for "filesystems without rename() operation
+		 * and device file" or "path without vfsmount" or "absolute
+		 * name is unavailable" cases.
 		 */
 #if LINUX_VERSION_CODE < KERNEL_VERSION(3, 17, 0)
-		if (!path->mnt || (inode->i_op && !inode->i_op->rename))
+		if (!path->mnt ||
+		    (inode->i_op && !inode->i_op->rename &&
+		     !(sb->s_type->fs_flags & FS_REQUIRES_DEV)))
 			pos = ERR_PTR(-EINVAL);
 		else {
 			/* Get absolute name for the rest. */
@@ -559,13 +561,16 @@ char *ccs_realpath(const struct path *path)
 						 buf_len - 1);
 #elif LINUX_VERSION_CODE < KERNEL_VERSION(4, 9, 0)
 		if (!path->mnt ||
-		    (!inode->i_op->rename && !inode->i_op->rename2))
+		    (!inode->i_op->rename && !inode->i_op->rename2 &&
+		     !(sb->s_type->fs_flags & FS_REQUIRES_DEV)))
 			pos = ccs_get_local_path(path->dentry, buf,
 						 buf_len - 1);
 		else
 			pos = ccs_get_absolute_path(path, buf, buf_len - 1);
 #else
-		if (!path->mnt || !inode->i_op->rename)
+		if (!path->mnt ||
+		    (!inode->i_op->rename &&
+		     !(sb->s_type->fs_flags & FS_REQUIRES_DEV)))
 			pos = ccs_get_local_path(path->dentry, buf,
 						 buf_len - 1);
 		else
